Development — SoL 4 user manual

# Development

SoL development is carried on in a git repository on GitLab, that is automatically mirrored on Bitbucket.

You can visit the activity page to see what's happened recently.

If you are a developer, you are more than welcome to fork it and adapt or improve it to fit your needs, and I will happily integrate back the changes you may contribute.

Alternatively you can translate it into another language, using the online Weblate service.

There is also some technical documentation automatically extracted from the sources.

## Donations

Since the beginning1 I sustained all the maintenance costs of SoL, both in terms of study and development of the software, and the hosting of the service, usable and browsable for free.

Since some time ECC sponsors the development of SoL, bearing part of the server maintenance costs.

If you use SoL to organize tournaments, in particular of national relevance, please consider the opportunity of making a donation contributing to its development and maintenance, so that the service may be keep going.

1

  I started writing `Scarry` in October 1999, while `SoL` saw the light just under ten years later!

### Liberapay

### PayPal